@@ -6,14 +6,17 @@ from .save import get_save_client
 
 
 def check_s3():
+    print("Checking S3 connection...")
     get_save_client("s3")
 
 
 def check_db():
+    print("Checking DB connection...")
     get_DB_client(settings.dbm)
 
 
 def check_cas():
+    print("Checking CAS connection")
     CAS(save="local", **settings.cas).head()
 
 
