@@ -37,9 +37,6 @@ class SQLServer(Abstract_DB):
 
         conn_str = s.get("CONN_STR", None)
 
-        credentials_kargs = {}
-        if s.get("USER", None):
-            credentials_kargs = {"user": s.user, "password": s.password}
         try:
             connection = pyodbc.connect(
                 conn_str,
@@ -47,7 +44,8 @@ class SQLServer(Abstract_DB):
                 server=s.ip,
                 port=s.get("PORT", None),
                 database=s.base,
-                **credentials_kargs,
+                user=s.get("USER", None),
+                password=s.get("PASSWORD", None),
             )
         except BaseException as e:
             logger.error(f"Can't set up a connection with {s.ip}/{s.base}, {e}")
